@@ -24,13 +24,19 @@ _DB = seqdb.get()
 
 def get_mnemonic(direction, prefix, p, i, f):
 
+    params = p.split(";")
+
     if len(p) == 0 or len(p) == len(prefix):
         length = 0
     else:
         key = '%s CSI %s%s%s' % (direction, p, i, f)
         if key in _DB:
             return _DB[key] 
-        length = len(p.split(";"))
+        length = len()
+
+    key = '%s CSI %s%s;*%s%s' % (direction, prefix, params[0], i, f)
+    if key in _DB:
+        return _DB[key] 
 
     key = '%s CSI %s[%d]%s%s' % (direction, prefix, length, i, f)
     if key in _DB:
